# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/3454/gift/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/3454/gift/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "3454\\Gift\\": "packages/3454/gift/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        3454\Gift\Providers\GiftServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Gift'  => 3454\Gift\Facades\Gift::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=3454\\GiftTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="3454\Gift\Providers\GiftServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="3454\Gift\Providers\GiftServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="3454\Gift\Providers\GiftServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/gift/{modulename}

**User**

    http://path-to-route-folder/user/gift/{modulename}

**Public**

    http://path-to-route-folder/gifts


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/gift/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/gift/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/gift/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/gift/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/gift/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/gift/{modulename}/{slug}
    METHOD: GET